@@ -5,7 +5,7 @@
 # @Email        : shawninjuly@gmai.com
 # ------------------------------------
 
-QINIU_DOMAIN = 'img.nanchuan.site'
+QINIU_DOMAIN = 'http://img.nanchuan.site'
 QINIU_BUCKET = "pfa"
 QINIU_AK     = 'Li-8HoZaqUHFzZ8l87WL-JzBRpjK7c1HTFgSoWso'
 QINIU_SK     = '_Y_ywcqqrmpDskjCrpH2A35iOQMjMHdIsdTsTbz0'
